@@ -86,6 +86,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.core
@@ -142,7 +144,7 @@ class CfnNotificationRule(
         event_type_ids: typing.Sequence[builtins.str],
         name: builtins.str,
         resource: builtins.str,
-        targets: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union["CfnNotificationRule.TargetProperty", aws_cdk.core.IResolvable]]],
+        targets: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[typing.Union["CfnNotificationRule.TargetProperty", typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]]],
         created_by: typing.Optional[builtins.str] = None,
         event_type_id: typing.Optional[builtins.str] = None,
         status: typing.Optional[builtins.str] = None,
@@ -164,6 +166,10 @@ class CfnNotificationRule(
         :param tags: A list of tags to apply to this notification rule. Key names cannot start with " ``aws`` ".
         :param target_address: ``AWS::CodeStarNotifications::NotificationRule.TargetAddress``.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnNotificationRule.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnNotificationRuleProps(
             detail_type=detail_type,
             event_type_ids=event_type_ids,
@@ -185,6 +191,9 @@ class CfnNotificationRule(
 
         :param inspector: - tree inspector to collect and process attributes.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnNotificationRule.inspect)
+            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
     @jsii.member(jsii_name="renderProperties")
@@ -195,6 +204,9 @@ class CfnNotificationRule(
         '''
         :param props: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnNotificationRule._render_properties)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
     @jsii.python.classproperty # type: ignore[misc]
@@ -240,6 +252,9 @@ class CfnNotificationRule(
 
     @detail_type.setter
     def detail_type(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "detail_type").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "detailType", value)
 
     @builtins.property # type: ignore[misc]
@@ -255,6 +270,9 @@ class CfnNotificationRule(
 
     @event_type_ids.setter
     def event_type_ids(self, value: typing.List[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "event_type_ids").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "eventTypeIds", value)
 
     @builtins.property # type: ignore[misc]
@@ -270,6 +288,9 @@ class CfnNotificationRule(
 
     @name.setter
     def name(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "name").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
     @builtins.property # type: ignore[misc]
@@ -285,6 +306,9 @@ class CfnNotificationRule(
 
     @resource.setter
     def resource(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "resource").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "resource", value)
 
     @builtins.property # type: ignore[misc]
@@ -303,6 +327,9 @@ class CfnNotificationRule(
         self,
         value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnNotificationRule.TargetProperty", aws_cdk.core.IResolvable]]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "targets").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "targets", value)
 
     @builtins.property # type: ignore[misc]
@@ -316,6 +343,9 @@ class CfnNotificationRule(
 
     @created_by.setter
     def created_by(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "created_by").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "createdBy", value)
 
     @builtins.property # type: ignore[misc]
@@ -329,6 +359,9 @@ class CfnNotificationRule(
 
     @event_type_id.setter
     def event_type_id(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "event_type_id").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "eventTypeId", value)
 
     @builtins.property # type: ignore[misc]
@@ -344,6 +377,9 @@ class CfnNotificationRule(
 
     @status.setter
     def status(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "status").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "status", value)
 
     @builtins.property # type: ignore[misc]
@@ -357,6 +393,9 @@ class CfnNotificationRule(
 
     @target_address.setter
     def target_address(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "target_address").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "targetAddress", value)
 
     @jsii.data_type(
@@ -390,6 +429,10 @@ class CfnNotificationRule(
                     target_type="targetType"
                 )
             '''
+            if __debug__:
+                type_hints = typing.get_type_hints(CfnNotificationRule.TargetProperty.__init__)
+                check_type(argname="argument target_address", value=target_address, expected_type=type_hints["target_address"])
+                check_type(argname="argument target_type", value=target_type, expected_type=type_hints["target_type"])
             self._values: typing.Dict[str, typing.Any] = {
                 "target_address": target_address,
                 "target_type": target_type,
@@ -454,7 +497,7 @@ class CfnNotificationRuleProps:
         event_type_ids: typing.Sequence[builtins.str],
         name: builtins.str,
         resource: builtins.str,
-        targets: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[CfnNotificationRule.TargetProperty, aws_cdk.core.IResolvable]]],
+        targets: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[typing.Union[CfnNotificationRule.TargetProperty, typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]]],
         created_by: typing.Optional[builtins.str] = None,
         event_type_id: typing.Optional[builtins.str] = None,
         status: typing.Optional[builtins.str] = None,
@@ -503,6 +546,18 @@ class CfnNotificationRuleProps:
                 target_address="targetAddress"
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnNotificationRuleProps.__init__)
+            check_type(argname="argument detail_type", value=detail_type, expected_type=type_hints["detail_type"])
+            check_type(argname="argument event_type_ids", value=event_type_ids, expected_type=type_hints["event_type_ids"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
+            check_type(argname="argument targets", value=targets, expected_type=type_hints["targets"])
+            check_type(argname="argument created_by", value=created_by, expected_type=type_hints["created_by"])
+            check_type(argname="argument event_type_id", value=event_type_id, expected_type=type_hints["event_type_id"])
+            check_type(argname="argument status", value=status, expected_type=type_hints["status"])
+            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
+            check_type(argname="argument target_address", value=target_address, expected_type=type_hints["target_address"])
         self._values: typing.Dict[str, typing.Any] = {
             "detail_type": detail_type,
             "event_type_ids": event_type_ids,
@@ -700,6 +755,9 @@ class _INotificationRuleProxy(
 
         :return: boolean - return true if it had any effect
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(INotificationRule.add_target)
+            check_type(argname="argument target", value=target, expected_type=type_hints["target"])
         return typing.cast(builtins.bool, jsii.invoke(self, "addTarget", [target]))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
@@ -736,6 +794,9 @@ class _INotificationRuleSourceProxy:
 
         :param scope: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(INotificationRuleSource.bind_as_notification_rule_source)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
         return typing.cast("NotificationRuleSourceConfig", jsii.invoke(self, "bindAsNotificationRuleSource", [scope]))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
@@ -772,6 +833,9 @@ class _INotificationRuleTargetProxy:
 
         :param scope: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(INotificationRuleTarget.bind_as_notification_rule_target)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
         return typing.cast("NotificationRuleTargetConfig", jsii.invoke(self, "bindAsNotificationRuleTarget", [scope]))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
@@ -838,6 +902,10 @@ class NotificationRule(
         :param enabled: The status of the notification rule. If the enabled is set to DISABLED, notifications aren't sent for the notification rule. Default: true
         :param notification_rule_name: The name for the notification rule. Notification rule names must be unique in your AWS account. Default: - generated from the ``id``
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(NotificationRule.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = NotificationRuleProps(
             events=events,
             source=source,
@@ -863,6 +931,11 @@ class NotificationRule(
         :param id: The construct's name.
         :param notification_rule_arn: Notification rule ARN (i.e. arn:aws:codestar-notifications:::notificationrule/01234abcde).
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(NotificationRule.from_notification_rule_arn)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument notification_rule_arn", value=notification_rule_arn, expected_type=type_hints["notification_rule_arn"])
         return typing.cast(INotificationRule, jsii.sinvoke(cls, "fromNotificationRuleArn", [scope, id, notification_rule_arn]))
 
     @jsii.member(jsii_name="addTarget")
@@ -871,6 +944,9 @@ class NotificationRule(
 
         :param target: The SNS topic or AWS Chatbot Slack target.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(NotificationRule.add_target)
+            check_type(argname="argument target", value=target, expected_type=type_hints["target"])
         return typing.cast(builtins.bool, jsii.invoke(self, "addTarget", [target]))
 
     @builtins.property # type: ignore[misc]
@@ -920,6 +996,11 @@ class NotificationRuleOptions:
                 notification_rule_name="notificationRuleName"
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(NotificationRuleOptions.__init__)
+            check_type(argname="argument detail_type", value=detail_type, expected_type=type_hints["detail_type"])
+            check_type(argname="argument enabled", value=enabled, expected_type=type_hints["enabled"])
+            check_type(argname="argument notification_rule_name", value=notification_rule_name, expected_type=type_hints["notification_rule_name"])
         self._values: typing.Dict[str, typing.Any] = {}
         if detail_type is not None:
             self._values["detail_type"] = detail_type
@@ -1034,6 +1115,14 @@ class NotificationRuleProps(NotificationRuleOptions):
             )
             rule.add_target(slack)
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(NotificationRuleProps.__init__)
+            check_type(argname="argument detail_type", value=detail_type, expected_type=type_hints["detail_type"])
+            check_type(argname="argument enabled", value=enabled, expected_type=type_hints["enabled"])
+            check_type(argname="argument notification_rule_name", value=notification_rule_name, expected_type=type_hints["notification_rule_name"])
+            check_type(argname="argument events", value=events, expected_type=type_hints["events"])
+            check_type(argname="argument source", value=source, expected_type=type_hints["source"])
+            check_type(argname="argument targets", value=targets, expected_type=type_hints["targets"])
         self._values: typing.Dict[str, typing.Any] = {
             "events": events,
             "source": source,
@@ -1149,6 +1238,9 @@ class NotificationRuleSourceConfig:
                 source_arn="sourceArn"
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(NotificationRuleSourceConfig.__init__)
+            check_type(argname="argument source_arn", value=source_arn, expected_type=type_hints["source_arn"])
         self._values: typing.Dict[str, typing.Any] = {
             "source_arn": source_arn,
         }
@@ -1202,6 +1294,10 @@ class NotificationRuleTargetConfig:
                 target_type="targetType"
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(NotificationRuleTargetConfig.__init__)
+            check_type(argname="argument target_address", value=target_address, expected_type=type_hints["target_address"])
+            check_type(argname="argument target_type", value=target_type, expected_type=type_hints["target_type"])
         self._values: typing.Dict[str, typing.Any] = {
             "target_address": target_address,
             "target_type": target_type,
